@@ -58,6 +58,12 @@ def notify(title='UpImg', message=''):
     return True
 
 
+def get_desktop_path():
+    import winreg
+    key = winreg.OpenKey(winreg.HKEY_CURRENT_USER, r'Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders')
+    return winreg.QueryValueEx(key, 'Desktop')[0]
+
+
 def set_global_hot_key():
     """
     HOT KEY code
@@ -73,19 +79,26 @@ def set_global_hot_key():
 
     # 要创建快捷方式的文件的完整路径
     exe_path = os.path.join(sys.base_prefix, 'Scripts', 'upimg.exe')
+    exe_path = os.path.join(r'D:\Anaconda3', 'Scripts', 'upimg.exe')
     iconname = os.path.join(os.path.dirname(__file__), 'notification.ico')
-    # 将要在APPDATA\Roaming创建快捷方式
-    lnk_path = os.path.join(os.getenv("APPDATA"), 'UpImg.lnk')
+    # 在桌面生成创建快捷方式（其他路径快捷键会失效）
+    # lnk_path = os.path.join(os.getenv("APPDATA"), 'UpImg.lnk')
+    lnk_path = os.path.join(get_desktop_path(), 'UpImg.lnk')
 
     shortcut = pythoncom.CoCreateInstance(
         shell.CLSID_ShellLink, None,
         pythoncom.CLSCTX_INPROC_SERVER, shell.IID_IShellLink)
     shortcut.SetPath(exe_path)
     # Ctrl + Alt + A
-    hot_key = (0x02 << 8) | (0x04 << 8) | 0x41
+    # hot_key = (0x02 << 8) | (0x04 << 8) | 0x41
+    hot_key = (0x02 << 8) | 0x31
     shortcut.SetHotkey(hot_key)
     # 设置快捷方式的起始位置, 不然会出现找不到辅助文件的情况
     shortcut.SetWorkingDirectory(os.path.dirname(exe_path))
     # 可有可无，没有就默认使用文件本身的图标
     shortcut.SetIconLocation(iconname, 0)
+    # https://docs.microsoft.com/en-us/windows/win32/api/shobjidl_core/nf-shobjidl_core-ishelllinka-setshowcmd
+    # SW_SHOWNORMAL 1 | SW_SHOWMINIMIZED 2(无效) | SW_SHOWMINNOACTIVE 7 | SW_SHOWMAXIMIZED 3
+    shortcut.SetShowCmd(7)
     shortcut.QueryInterface(pythoncom.IID_IPersistFile).Save(lnk_path, 0)
+
